summaryrefslogtreecommitdiff
path: root/TAO/tao/ORB.h
diff options
context:
space:
mode:
authorcoryan <coryan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-03-24 04:43:59 +0000
committercoryan <coryan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-03-24 04:43:59 +0000
commite734c1d9923c66dc191d825dd1cdb79d6c15f5f1 (patch)
treeee03afe97556edc859fb1fbfa966bf75229e87aa /TAO/tao/ORB.h
parent9648d43c4d91407a37f7d6e75e948b807a0700b0 (diff)
downloadATCD-e734c1d9923c66dc191d825dd1cdb79d6c15f5f1.tar.gz
ChangeLogTag:Tue Mar 23 22:33:43 1999 Carlos O'Ryan <coryan@cs.wustl.edu>
Diffstat (limited to 'TAO/tao/ORB.h')
-rw-r--r--TAO/tao/ORB.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/TAO/tao/ORB.h b/TAO/tao/ORB.h
index 5e8b8f6c486..473ac2eb6e3 100644
--- a/TAO/tao/ORB.h
+++ b/TAO/tao/ORB.h
@@ -89,7 +89,7 @@ typedef struct TAO_Leader_Follower_Info_Struct
// thread ID of the leader thread (protected)
} TAO_Leader_Follower_Info;
-class STUB_Object;
+class TAO_Stub;
// Forward declarations.
class TAO_Export CORBA_String_var
@@ -244,11 +244,11 @@ public:
// this is typically eventually given to <string_to_object()> as an
// argument.
- virtual TAO_ServantBase *_get_collocated_servant (STUB_Object *p) = 0;
+ virtual TAO_ServantBase *_get_collocated_servant (TAO_Stub *p) = 0;
// Return the object pointer of an collocated object it there is
// one, otherwise, return 0. Each type of ORB, e. g., IIOP ORB,
// must implement this and determine what is a collocated object
// based on information provided in the STUB_Object.
virtual int _tao_add_to_IOR_table (ACE_CString object_id, CORBA::Object_ptr obj) = 0;
// Add a mapping ObjectID->IOR to the table.
@@ -329,7 +329,7 @@ public:
const TAO_POA_Policies *policies = 0);
// Resolve the POA.
- STUB_Object *create_stub_object (const TAO_ObjectKey &key,
+ TAO_Stub *create_stub_object (const TAO_ObjectKey &key,
const char *type_id,
CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
// Makes sure that the ORB is open and then creates an IIOP object
@@ -244,11 +244,11 @@ public:
// one, otherwise, return 0. Each type of ORB, e. g., IIOP ORB,
// must implement this and determine what is a collocated object
- // based on information provided in the STUB_Object.
+ // based on information provided in the TAO_Stub.
virtual int _tao_add_to_IOR_table (ACE_CString object_id, CORBA::Object_ptr obj) = 0;
// Add a mapping ObjectID->IOR to the table.